General information
===================

Here we describe how the napari-boxmanager is generally structured and what are its elements.

Installation
------------

Start napari
------------

Command line
^^^^^^^^^^^^

GUI
^^^

Overview
---------

Describe how the GUI is structured and the give a general description of its parts


Boxmanager Module
^^^^^^^^^^^^^^^^^

Add Layer Module
^^^^^^^^^^^^^^^^

Bandpass Module
^^^^^^^^^^^^^^^

Matching Module
^^^^^^^^^^^^^^^

Describe how it works. Important: The star has to be at the same position for images and box
